# coding: utf-8

"""
    wd-domain-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wd_domain_service.configuration import Configuration


class EventDetailInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'scene_id': 'str',
        'name': 'str',
        'discharge_type': 'int',
        'start_time': 'datetime',
        'end_time': 'datetime',
        'location': 'str',
        'river_id': 'str',
        'chainage': 'float',
        'discharge_value': 'Null',
        'event_type': 'str',
        'components': 'list[ComponentDetailInfo]'
    }

    attribute_map = {
        'id': 'id',
        'scene_id': 'sceneId',
        'name': 'name',
        'discharge_type': 'dischargeType',
        'start_time': 'startTime',
        'end_time': 'endTime',
        'location': 'location',
        'river_id': 'riverID',
        'chainage': 'chainage',
        'discharge_value': 'dischargeValue',
        'event_type': 'eventType',
        'components': 'components'
    }

    def __init__(self, id=None, scene_id=None, name=None, discharge_type=None, start_time=None, end_time=None, location=None, river_id=None, chainage=None, discharge_value=None, event_type=None, components=None, local_vars_configuration=None):  # noqa: E501
        """EventDetailInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._scene_id = None
        self._name = None
        self._discharge_type = None
        self._start_time = None
        self._end_time = None
        self._location = None
        self._river_id = None
        self._chainage = None
        self._discharge_value = None
        self._event_type = None
        self._components = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if scene_id is not None:
            self.scene_id = scene_id
        self.name = name
        if discharge_type is not None:
            self.discharge_type = discharge_type
        if start_time is not None:
            self.start_time = start_time
        if end_time is not None:
            self.end_time = end_time
        self.location = location
        self.river_id = river_id
        self.chainage = chainage
        if discharge_value is not None:
            self.discharge_value = discharge_value
        self.event_type = event_type
        self.components = components

    @property
    def id(self):
        """Gets the id of this EventDetailInfo.  # noqa: E501


        :return: The id of this EventDetailInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this EventDetailInfo.


        :param id: The id of this EventDetailInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def scene_id(self):
        """Gets the scene_id of this EventDetailInfo.  # noqa: E501

        情景id  # noqa: E501

        :return: The scene_id of this EventDetailInfo.  # noqa: E501
        :rtype: str
        """
        return self._scene_id

    @scene_id.setter
    def scene_id(self, scene_id):
        """Sets the scene_id of this EventDetailInfo.

        情景id  # noqa: E501

        :param scene_id: The scene_id of this EventDetailInfo.  # noqa: E501
        :type: str
        """

        self._scene_id = scene_id

    @property
    def name(self):
        """Gets the name of this EventDetailInfo.  # noqa: E501

        事件名  # noqa: E501

        :return: The name of this EventDetailInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this EventDetailInfo.

        事件名  # noqa: E501

        :param name: The name of this EventDetailInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def discharge_type(self):
        """Gets the discharge_type of this EventDetailInfo.  # noqa: E501

        0-TimeSeries(时间序列) 1-Constant(常量)   # noqa: E501

        :return: The discharge_type of this EventDetailInfo.  # noqa: E501
        :rtype: int
        """
        return self._discharge_type

    @discharge_type.setter
    def discharge_type(self, discharge_type):
        """Sets the discharge_type of this EventDetailInfo.

        0-TimeSeries(时间序列) 1-Constant(常量)   # noqa: E501

        :param discharge_type: The discharge_type of this EventDetailInfo.  # noqa: E501
        :type: int
        """
        allowed_values = [0, 1]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and discharge_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `discharge_type` ({0}), must be one of {1}"  # noqa: E501
                .format(discharge_type, allowed_values)
            )

        self._discharge_type = discharge_type

    @property
    def start_time(self):
        """Gets the start_time of this EventDetailInfo.  # noqa: E501

        开始时间  # noqa: E501

        :return: The start_time of this EventDetailInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this EventDetailInfo.

        开始时间  # noqa: E501

        :param start_time: The start_time of this EventDetailInfo.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this EventDetailInfo.  # noqa: E501

        结束时间  # noqa: E501

        :return: The end_time of this EventDetailInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this EventDetailInfo.

        结束时间  # noqa: E501

        :param end_time: The end_time of this EventDetailInfo.  # noqa: E501
        :type: datetime
        """

        self._end_time = end_time

    @property
    def location(self):
        """Gets the location of this EventDetailInfo.  # noqa: E501

        事件位置，对于爆管事件和水质事件，填模型id  # noqa: E501

        :return: The location of this EventDetailInfo.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this EventDetailInfo.

        事件位置，对于爆管事件和水质事件，填模型id  # noqa: E501

        :param location: The location of this EventDetailInfo.  # noqa: E501
        :type: str
        """

        self._location = location

    @property
    def river_id(self):
        """Gets the river_id of this EventDetailInfo.  # noqa: E501


        :return: The river_id of this EventDetailInfo.  # noqa: E501
        :rtype: str
        """
        return self._river_id

    @river_id.setter
    def river_id(self, river_id):
        """Sets the river_id of this EventDetailInfo.


        :param river_id: The river_id of this EventDetailInfo.  # noqa: E501
        :type: str
        """

        self._river_id = river_id

    @property
    def chainage(self):
        """Gets the chainage of this EventDetailInfo.  # noqa: E501


        :return: The chainage of this EventDetailInfo.  # noqa: E501
        :rtype: float
        """
        return self._chainage

    @chainage.setter
    def chainage(self, chainage):
        """Sets the chainage of this EventDetailInfo.


        :param chainage: The chainage of this EventDetailInfo.  # noqa: E501
        :type: float
        """

        self._chainage = chainage

    @property
    def discharge_value(self):
        """Gets the discharge_value of this EventDetailInfo.  # noqa: E501

        排水量/泄水量  # noqa: E501

        :return: The discharge_value of this EventDetailInfo.  # noqa: E501
        :rtype: Null
        """
        return self._discharge_value

    @discharge_value.setter
    def discharge_value(self, discharge_value):
        """Sets the discharge_value of this EventDetailInfo.

        排水量/泄水量  # noqa: E501

        :param discharge_value: The discharge_value of this EventDetailInfo.  # noqa: E501
        :type: Null
        """

        self._discharge_value = discharge_value

    @property
    def event_type(self):
        """Gets the event_type of this EventDetailInfo.  # noqa: E501

        事件类型  # noqa: E501

        :return: The event_type of this EventDetailInfo.  # noqa: E501
        :rtype: str
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this EventDetailInfo.

        事件类型  # noqa: E501

        :param event_type: The event_type of this EventDetailInfo.  # noqa: E501
        :type: str
        """

        self._event_type = event_type

    @property
    def components(self):
        """Gets the components of this EventDetailInfo.  # noqa: E501

        污染物（污染物事故使用）  # noqa: E501

        :return: The components of this EventDetailInfo.  # noqa: E501
        :rtype: list[ComponentDetailInfo]
        """
        return self._components

    @components.setter
    def components(self, components):
        """Sets the components of this EventDetailInfo.

        污染物（污染物事故使用）  # noqa: E501

        :param components: The components of this EventDetailInfo.  # noqa: E501
        :type: list[ComponentDetailInfo]
        """

        self._components = components

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EventDetailInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EventDetailInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    wwtp-paas-infrastructure-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_infrastructure_service.configuration import Configuration


class BaseProductLineInOut(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'production_line_code': 'str',
        'name': 'str',
        'inlet': 'str',
        'inlet_name': 'str',
        'outlet': 'str',
        'outlet_name': 'str',
        'hrt_code': 'str',
        'hrt': 'float',
        'model_name': 'str',
        'dosage_group': 'str',
        'dosage_category': 'str'
    }

    attribute_map = {
        'id': 'id',
        'production_line_code': 'productionLineCode',
        'name': 'name',
        'inlet': 'inlet',
        'inlet_name': 'inletName',
        'outlet': 'outlet',
        'outlet_name': 'outletName',
        'hrt_code': 'hrtCode',
        'hrt': 'hrt',
        'model_name': 'modelName',
        'dosage_group': 'dosageGroup',
        'dosage_category': 'dosageCategory'
    }

    def __init__(self, id=None, production_line_code=None, name=None, inlet=None, inlet_name=None, outlet=None, outlet_name=None, hrt_code=None, hrt=None, model_name=None, dosage_group=None, dosage_category=None, local_vars_configuration=None):  # noqa: E501
        """BaseProductLineInOut - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._production_line_code = None
        self._name = None
        self._inlet = None
        self._inlet_name = None
        self._outlet = None
        self._outlet_name = None
        self._hrt_code = None
        self._hrt = None
        self._model_name = None
        self._dosage_group = None
        self._dosage_category = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.production_line_code = production_line_code
        self.name = name
        self.inlet = inlet
        self.inlet_name = inlet_name
        self.outlet = outlet
        self.outlet_name = outlet_name
        self.hrt_code = hrt_code
        if hrt is not None:
            self.hrt = hrt
        self.model_name = model_name
        self.dosage_group = dosage_group
        self.dosage_category = dosage_category

    @property
    def id(self):
        """Gets the id of this BaseProductLineInOut.  # noqa: E501


        :return: The id of this BaseProductLineInOut.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BaseProductLineInOut.


        :param id: The id of this BaseProductLineInOut.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def production_line_code(self):
        """Gets the production_line_code of this BaseProductLineInOut.  # noqa: E501

        工艺线代码 product line code  # noqa: E501

        :return: The production_line_code of this BaseProductLineInOut.  # noqa: E501
        :rtype: str
        """
        return self._production_line_code

    @production_line_code.setter
    def production_line_code(self, production_line_code):
        """Sets the production_line_code of this BaseProductLineInOut.

        工艺线代码 product line code  # noqa: E501

        :param production_line_code: The production_line_code of this BaseProductLineInOut.  # noqa: E501
        :type: str
        """

        self._production_line_code = production_line_code

    @property
    def name(self):
        """Gets the name of this BaseProductLineInOut.  # noqa: E501

        工艺线名称 product line name  # noqa: E501

        :return: The name of this BaseProductLineInOut.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BaseProductLineInOut.

        工艺线名称 product line name  # noqa: E501

        :param name: The name of this BaseProductLineInOut.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def inlet(self):
        """Gets the inlet of this BaseProductLineInOut.  # noqa: E501

        进水口代码 inlet code  # noqa: E501

        :return: The inlet of this BaseProductLineInOut.  # noqa: E501
        :rtype: str
        """
        return self._inlet

    @inlet.setter
    def inlet(self, inlet):
        """Sets the inlet of this BaseProductLineInOut.

        进水口代码 inlet code  # noqa: E501

        :param inlet: The inlet of this BaseProductLineInOut.  # noqa: E501
        :type: str
        """

        self._inlet = inlet

    @property
    def inlet_name(self):
        """Gets the inlet_name of this BaseProductLineInOut.  # noqa: E501

        进水口名称  # noqa: E501

        :return: The inlet_name of this BaseProductLineInOut.  # noqa: E501
        :rtype: str
        """
        return self._inlet_name

    @inlet_name.setter
    def inlet_name(self, inlet_name):
        """Sets the inlet_name of this BaseProductLineInOut.

        进水口名称  # noqa: E501

        :param inlet_name: The inlet_name of this BaseProductLineInOut.  # noqa: E501
        :type: str
        """

        self._inlet_name = inlet_name

    @property
    def outlet(self):
        """Gets the outlet of this BaseProductLineInOut.  # noqa: E501

        出水口代码 outlet code  # noqa: E501

        :return: The outlet of this BaseProductLineInOut.  # noqa: E501
        :rtype: str
        """
        return self._outlet

    @outlet.setter
    def outlet(self, outlet):
        """Sets the outlet of this BaseProductLineInOut.

        出水口代码 outlet code  # noqa: E501

        :param outlet: The outlet of this BaseProductLineInOut.  # noqa: E501
        :type: str
        """

        self._outlet = outlet

    @property
    def outlet_name(self):
        """Gets the outlet_name of this BaseProductLineInOut.  # noqa: E501

        出水口名称  # noqa: E501

        :return: The outlet_name of this BaseProductLineInOut.  # noqa: E501
        :rtype: str
        """
        return self._outlet_name

    @outlet_name.setter
    def outlet_name(self, outlet_name):
        """Sets the outlet_name of this BaseProductLineInOut.

        出水口名称  # noqa: E501

        :param outlet_name: The outlet_name of this BaseProductLineInOut.  # noqa: E501
        :type: str
        """

        self._outlet_name = outlet_name

    @property
    def hrt_code(self):
        """Gets the hrt_code of this BaseProductLineInOut.  # noqa: E501

        HRT代码 hrt code  # noqa: E501

        :return: The hrt_code of this BaseProductLineInOut.  # noqa: E501
        :rtype: str
        """
        return self._hrt_code

    @hrt_code.setter
    def hrt_code(self, hrt_code):
        """Sets the hrt_code of this BaseProductLineInOut.

        HRT代码 hrt code  # noqa: E501

        :param hrt_code: The hrt_code of this BaseProductLineInOut.  # noqa: E501
        :type: str
        """

        self._hrt_code = hrt_code

    @property
    def hrt(self):
        """Gets the hrt of this BaseProductLineInOut.  # noqa: E501

        水力停留时间（单位：小时） hrt value in hour  # noqa: E501

        :return: The hrt of this BaseProductLineInOut.  # noqa: E501
        :rtype: float
        """
        return self._hrt

    @hrt.setter
    def hrt(self, hrt):
        """Sets the hrt of this BaseProductLineInOut.

        水力停留时间（单位：小时） hrt value in hour  # noqa: E501

        :param hrt: The hrt of this BaseProductLineInOut.  # noqa: E501
        :type: float
        """

        self._hrt = hrt

    @property
    def model_name(self):
        """Gets the model_name of this BaseProductLineInOut.  # noqa: E501

        模板模型名称 template model name  # noqa: E501

        :return: The model_name of this BaseProductLineInOut.  # noqa: E501
        :rtype: str
        """
        return self._model_name

    @model_name.setter
    def model_name(self, model_name):
        """Sets the model_name of this BaseProductLineInOut.

        模板模型名称 template model name  # noqa: E501

        :param model_name: The model_name of this BaseProductLineInOut.  # noqa: E501
        :type: str
        """

        self._model_name = model_name

    @property
    def dosage_group(self):
        """Gets the dosage_group of this BaseProductLineInOut.  # noqa: E501

        智能加药分组 dosage group  # noqa: E501

        :return: The dosage_group of this BaseProductLineInOut.  # noqa: E501
        :rtype: str
        """
        return self._dosage_group

    @dosage_group.setter
    def dosage_group(self, dosage_group):
        """Sets the dosage_group of this BaseProductLineInOut.

        智能加药分组 dosage group  # noqa: E501

        :param dosage_group: The dosage_group of this BaseProductLineInOut.  # noqa: E501
        :type: str
        """

        self._dosage_group = dosage_group

    @property
    def dosage_category(self):
        """Gets the dosage_category of this BaseProductLineInOut.  # noqa: E501

        包含加药的类型，逗号分隔 dosing type, seperated by comma  # noqa: E501

        :return: The dosage_category of this BaseProductLineInOut.  # noqa: E501
        :rtype: str
        """
        return self._dosage_category

    @dosage_category.setter
    def dosage_category(self, dosage_category):
        """Sets the dosage_category of this BaseProductLineInOut.

        包含加药的类型，逗号分隔 dosing type, seperated by comma  # noqa: E501

        :param dosage_category: The dosage_category of this BaseProductLineInOut.  # noqa: E501
        :type: str
        """

        self._dosage_category = dosage_category

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BaseProductLineInOut):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BaseProductLineInOut):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    identity-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_identity_service.configuration import Configuration


class MicroServiceOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'service_key': 'str',
        'service_name': 'str',
        'develop_voice': 'str',
        'is_gateway_auth': 'bool',
        'manager_name': 'str',
        'remarks': 'str',
        'creation_time': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'service_key': 'serviceKey',
        'service_name': 'serviceName',
        'develop_voice': 'developVoice',
        'is_gateway_auth': 'isGatewayAuth',
        'manager_name': 'managerName',
        'remarks': 'remarks',
        'creation_time': 'creationTime'
    }

    def __init__(self, id=None, service_key=None, service_name=None, develop_voice=None, is_gateway_auth=None, manager_name=None, remarks=None, creation_time=None, local_vars_configuration=None):  # noqa: E501
        """MicroServiceOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._service_key = None
        self._service_name = None
        self._develop_voice = None
        self._is_gateway_auth = None
        self._manager_name = None
        self._remarks = None
        self._creation_time = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.service_key = service_key
        self.service_name = service_name
        self.develop_voice = develop_voice
        if is_gateway_auth is not None:
            self.is_gateway_auth = is_gateway_auth
        self.manager_name = manager_name
        self.remarks = remarks
        if creation_time is not None:
            self.creation_time = creation_time

    @property
    def id(self):
        """Gets the id of this MicroServiceOutput.  # noqa: E501

        微服务Id micro service id  # noqa: E501

        :return: The id of this MicroServiceOutput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MicroServiceOutput.

        微服务Id micro service id  # noqa: E501

        :param id: The id of this MicroServiceOutput.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def service_key(self):
        """Gets the service_key of this MicroServiceOutput.  # noqa: E501

        微服务标识 micro service key  # noqa: E501

        :return: The service_key of this MicroServiceOutput.  # noqa: E501
        :rtype: str
        """
        return self._service_key

    @service_key.setter
    def service_key(self, service_key):
        """Sets the service_key of this MicroServiceOutput.

        微服务标识 micro service key  # noqa: E501

        :param service_key: The service_key of this MicroServiceOutput.  # noqa: E501
        :type: str
        """

        self._service_key = service_key

    @property
    def service_name(self):
        """Gets the service_name of this MicroServiceOutput.  # noqa: E501

        微服务名称 micro service name  # noqa: E501

        :return: The service_name of this MicroServiceOutput.  # noqa: E501
        :rtype: str
        """
        return self._service_name

    @service_name.setter
    def service_name(self, service_name):
        """Sets the service_name of this MicroServiceOutput.

        微服务名称 micro service name  # noqa: E501

        :param service_name: The service_name of this MicroServiceOutput.  # noqa: E501
        :type: str
        """

        self._service_name = service_name

    @property
    def develop_voice(self):
        """Gets the develop_voice of this MicroServiceOutput.  # noqa: E501

        开发语言 develop language  # noqa: E501

        :return: The develop_voice of this MicroServiceOutput.  # noqa: E501
        :rtype: str
        """
        return self._develop_voice

    @develop_voice.setter
    def develop_voice(self, develop_voice):
        """Sets the develop_voice of this MicroServiceOutput.

        开发语言 develop language  # noqa: E501

        :param develop_voice: The develop_voice of this MicroServiceOutput.  # noqa: E501
        :type: str
        """

        self._develop_voice = develop_voice

    @property
    def is_gateway_auth(self):
        """Gets the is_gateway_auth of this MicroServiceOutput.  # noqa: E501

        是否需要网关鉴权 if require gateway authentication  # noqa: E501

        :return: The is_gateway_auth of this MicroServiceOutput.  # noqa: E501
        :rtype: bool
        """
        return self._is_gateway_auth

    @is_gateway_auth.setter
    def is_gateway_auth(self, is_gateway_auth):
        """Sets the is_gateway_auth of this MicroServiceOutput.

        是否需要网关鉴权 if require gateway authentication  # noqa: E501

        :param is_gateway_auth: The is_gateway_auth of this MicroServiceOutput.  # noqa: E501
        :type: bool
        """

        self._is_gateway_auth = is_gateway_auth

    @property
    def manager_name(self):
        """Gets the manager_name of this MicroServiceOutput.  # noqa: E501

        负责人 micro service manager  # noqa: E501

        :return: The manager_name of this MicroServiceOutput.  # noqa: E501
        :rtype: str
        """
        return self._manager_name

    @manager_name.setter
    def manager_name(self, manager_name):
        """Sets the manager_name of this MicroServiceOutput.

        负责人 micro service manager  # noqa: E501

        :param manager_name: The manager_name of this MicroServiceOutput.  # noqa: E501
        :type: str
        """

        self._manager_name = manager_name

    @property
    def remarks(self):
        """Gets the remarks of this MicroServiceOutput.  # noqa: E501

        备注 remarks  # noqa: E501

        :return: The remarks of this MicroServiceOutput.  # noqa: E501
        :rtype: str
        """
        return self._remarks

    @remarks.setter
    def remarks(self, remarks):
        """Sets the remarks of this MicroServiceOutput.

        备注 remarks  # noqa: E501

        :param remarks: The remarks of this MicroServiceOutput.  # noqa: E501
        :type: str
        """

        self._remarks = remarks

    @property
    def creation_time(self):
        """Gets the creation_time of this MicroServiceOutput.  # noqa: E501

        创建时间 create time  # noqa: E501

        :return: The creation_time of this MicroServiceOutput.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this MicroServiceOutput.

        创建时间 create time  # noqa: E501

        :param creation_time: The creation_time of this MicroServiceOutput.  # noqa: E501
        :type: datetime
        """

        self._creation_time = creation_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MicroServiceOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MicroServiceOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    竹园污水项目

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_zyws_service.api_client import ApiClient
from dhicn_zyws_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class ScenarioApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_v1_scenario_auto_forecast_create_run_post(self, **kwargs):  # noqa: E501
        """滚动计算，包括创建方案，设置边界，调用配水算法，发送ModelDriver模型计算  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_scenario_auto_forecast_create_run_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str tenant_id:
        :param str library_id:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_scenario_auto_forecast_create_run_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_scenario_auto_forecast_create_run_post_with_http_info(self, **kwargs):  # noqa: E501
        """滚动计算，包括创建方案，设置边界，调用配水算法，发送ModelDriver模型计算  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_scenario_auto_forecast_create_run_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str tenant_id:
        :param str library_id:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'tenant_id',
            'library_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_scenario_auto_forecast_create_run_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'tenant_id' in local_var_params and local_var_params['tenant_id'] is not None:  # noqa: E501
            query_params.append(('tenantId', local_var_params['tenant_id']))  # noqa: E501
        if 'library_id' in local_var_params and local_var_params['library_id'] is not None:  # noqa: E501
            query_params.append(('LibraryId', local_var_params['library_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/scenario/auto-forecast/create-run', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_scenario_auto_forecast_create_run_post_0(self, **kwargs):  # noqa: E501
        """滚动计算，包括创建方案，设置边界，调用配水算法，发送ModelDriver模型计算  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_scenario_auto_forecast_create_run_post_0(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str tenant_id:
        :param str library_id:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_scenario_auto_forecast_create_run_post_0_with_http_info(**kwargs)  # noqa: E501

    def api_v1_scenario_auto_forecast_create_run_post_0_with_http_info(self, **kwargs):  # noqa: E501
        """滚动计算，包括创建方案，设置边界，调用配水算法，发送ModelDriver模型计算  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_scenario_auto_forecast_create_run_post_0_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str tenant_id:
        :param str library_id:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'tenant_id',
            'library_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_scenario_auto_forecast_create_run_post_0" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'tenant_id' in local_var_params and local_var_params['tenant_id'] is not None:  # noqa: E501
            query_params.append(('tenantId', local_var_params['tenant_id']))  # noqa: E501
        if 'library_id' in local_var_params and local_var_params['library_id'] is not None:  # noqa: E501
            query_params.append(('LibraryId', local_var_params['library_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/scenario/auto-forecast/create-run', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_scenario_plan_create_post(self, **kwargs):  # noqa: E501
        """创建配水预案方案，同时补齐边界并入库  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_scenario_plan_create_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreatePlanScenarioInput create_plan_scenario_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ScenarioInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_scenario_plan_create_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_scenario_plan_create_post_with_http_info(self, **kwargs):  # noqa: E501
        """创建配水预案方案，同时补齐边界并入库  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_scenario_plan_create_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreatePlanScenarioInput create_plan_scenario_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ScenarioInfo, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'create_plan_scenario_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_scenario_plan_create_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_plan_scenario_input' in local_var_params:
            body_params = local_var_params['create_plan_scenario_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/scenario/plan/create', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ScenarioInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_scenario_plan_create_post_0(self, **kwargs):  # noqa: E501
        """创建配水预案方案，同时补齐边界并入库  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_scenario_plan_create_post_0(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreatePlanScenarioInput create_plan_scenario_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ScenarioInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_scenario_plan_create_post_0_with_http_info(**kwargs)  # noqa: E501

    def api_v1_scenario_plan_create_post_0_with_http_info(self, **kwargs):  # noqa: E501
        """创建配水预案方案，同时补齐边界并入库  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_scenario_plan_create_post_0_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreatePlanScenarioInput create_plan_scenario_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ScenarioInfo, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'create_plan_scenario_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_scenario_plan_create_post_0" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_plan_scenario_input' in local_var_params:
            body_params = local_var_params['create_plan_scenario_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/scenario/plan/create', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ScenarioInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_scenario_plan_delete_post(self, **kwargs):  # noqa: E501
        """删除方案，以及方案的边界数据，模型结果数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_scenario_plan_delete_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param IdsInput ids_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_scenario_plan_delete_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_scenario_plan_delete_post_with_http_info(self, **kwargs):  # noqa: E501
        """删除方案，以及方案的边界数据，模型结果数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_scenario_plan_delete_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param IdsInput ids_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'ids_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_scenario_plan_delete_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'ids_input' in local_var_params:
            body_params = local_var_params['ids_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/plain'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/scenario/plan/delete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_scenario_plan_delete_post_0(self, **kwargs):  # noqa: E501
        """删除方案，以及方案的边界数据，模型结果数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_scenario_plan_delete_post_0(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param IdsInput ids_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_scenario_plan_delete_post_0_with_http_info(**kwargs)  # noqa: E501

    def api_v1_scenario_plan_delete_post_0_with_http_info(self, **kwargs):  # noqa: E501
        """删除方案，以及方案的边界数据，模型结果数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_scenario_plan_delete_post_0_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param IdsInput ids_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'ids_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_scenario_plan_delete_post_0" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'ids_input' in local_var_params:
            body_params = local_var_params['ids_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/plain'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/scenario/plan/delete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_scenario_templates_get(self, **kwargs):  # noqa: E501
        """根据库的类型获取其下启用的模板方案列表  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_scenario_templates_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int library_type: 库的类型
        :param int business_type: 业务类型
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[ScenarioInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_scenario_templates_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_scenario_templates_get_with_http_info(self, **kwargs):  # noqa: E501
        """根据库的类型获取其下启用的模板方案列表  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_scenario_templates_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int library_type: 库的类型
        :param int business_type: 业务类型
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[ScenarioInfo], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'library_type',
            'business_type'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_scenario_templates_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'library_type' in local_var_params and local_var_params['library_type'] is not None:  # noqa: E501
            query_params.append(('libraryType', local_var_params['library_type']))  # noqa: E501
        if 'business_type' in local_var_params and local_var_params['business_type'] is not None:  # noqa: E501
            query_params.append(('businessType', local_var_params['business_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/scenario/templates', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ScenarioInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_scenario_templates_get_0(self, **kwargs):  # noqa: E501
        """根据库的类型获取其下启用的模板方案列表  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_scenario_templates_get_0(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int library_type: 库的类型
        :param int business_type: 业务类型
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[ScenarioInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_scenario_templates_get_0_with_http_info(**kwargs)  # noqa: E501

    def api_v1_scenario_templates_get_0_with_http_info(self, **kwargs):  # noqa: E501
        """根据库的类型获取其下启用的模板方案列表  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_scenario_templates_get_0_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int library_type: 库的类型
        :param int business_type: 业务类型
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[ScenarioInfo], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'library_type',
            'business_type'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_scenario_templates_get_0" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'library_type' in local_var_params and local_var_params['library_type'] is not None:  # noqa: E501
            query_params.append(('libraryType', local_var_params['library_type']))  # noqa: E501
        if 'business_type' in local_var_params and local_var_params['business_type'] is not None:  # noqa: E501
            query_params.append(('businessType', local_var_params['business_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/scenario/templates', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ScenarioInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_scenario_timed_delete_get(self, **kwargs):  # noqa: E501
        """定时批量删除指定方案库下的方案  删除三天前的方案，每天10分钟一个配水方案，一天生成6*24=144个，1小时一个厂内水动力方案，一天生成24个  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_scenario_timed_delete_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str tenant_id: 租户ID
        :param int library_type:
        :param int business_type:
        :param int days_to_keep:
        :param int page_index:
        :param int page_size:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_scenario_timed_delete_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_scenario_timed_delete_get_with_http_info(self, **kwargs):  # noqa: E501
        """定时批量删除指定方案库下的方案  删除三天前的方案，每天10分钟一个配水方案，一天生成6*24=144个，1小时一个厂内水动力方案，一天生成24个  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_scenario_timed_delete_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str tenant_id: 租户ID
        :param int library_type:
        :param int business_type:
        :param int days_to_keep:
        :param int page_index:
        :param int page_size:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'tenant_id',
            'library_type',
            'business_type',
            'days_to_keep',
            'page_index',
            'page_size'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_scenario_timed_delete_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'tenant_id' in local_var_params and local_var_params['tenant_id'] is not None:  # noqa: E501
            query_params.append(('tenantId', local_var_params['tenant_id']))  # noqa: E501
        if 'library_type' in local_var_params and local_var_params['library_type'] is not None:  # noqa: E501
            query_params.append(('libraryType', local_var_params['library_type']))  # noqa: E501
        if 'business_type' in local_var_params and local_var_params['business_type'] is not None:  # noqa: E501
            query_params.append(('businessType', local_var_params['business_type']))  # noqa: E501
        if 'days_to_keep' in local_var_params and local_var_params['days_to_keep'] is not None:  # noqa: E501
            query_params.append(('days_to_keep', local_var_params['days_to_keep']))  # noqa: E501
        if 'page_index' in local_var_params and local_var_params['page_index'] is not None:  # noqa: E501
            query_params.append(('pageIndex', local_var_params['page_index']))  # noqa: E501
        if 'page_size' in local_var_params and local_var_params['page_size'] is not None:  # noqa: E501
            query_params.append(('pageSize', local_var_params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/scenario/timed-delete', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_scenario_timed_delete_get_0(self, **kwargs):  # noqa: E501
        """定时批量删除指定方案库下的方案  删除三天前的方案，每天10分钟一个配水方案，一天生成6*24=144个，1小时一个厂内水动力方案，一天生成24个  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_scenario_timed_delete_get_0(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str tenant_id: 租户ID
        :param int library_type:
        :param int business_type:
        :param int days_to_keep:
        :param int page_index:
        :param int page_size:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_scenario_timed_delete_get_0_with_http_info(**kwargs)  # noqa: E501

    def api_v1_scenario_timed_delete_get_0_with_http_info(self, **kwargs):  # noqa: E501
        """定时批量删除指定方案库下的方案  删除三天前的方案，每天10分钟一个配水方案，一天生成6*24=144个，1小时一个厂内水动力方案，一天生成24个  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_scenario_timed_delete_get_0_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str tenant_id: 租户ID
        :param int library_type:
        :param int business_type:
        :param int days_to_keep:
        :param int page_index:
        :param int page_size:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'tenant_id',
            'library_type',
            'business_type',
            'days_to_keep',
            'page_index',
            'page_size'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_scenario_timed_delete_get_0" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'tenant_id' in local_var_params and local_var_params['tenant_id'] is not None:  # noqa: E501
            query_params.append(('tenantId', local_var_params['tenant_id']))  # noqa: E501
        if 'library_type' in local_var_params and local_var_params['library_type'] is not None:  # noqa: E501
            query_params.append(('libraryType', local_var_params['library_type']))  # noqa: E501
        if 'business_type' in local_var_params and local_var_params['business_type'] is not None:  # noqa: E501
            query_params.append(('businessType', local_var_params['business_type']))  # noqa: E501
        if 'days_to_keep' in local_var_params and local_var_params['days_to_keep'] is not None:  # noqa: E501
            query_params.append(('days_to_keep', local_var_params['days_to_keep']))  # noqa: E501
        if 'page_index' in local_var_params and local_var_params['page_index'] is not None:  # noqa: E501
            query_params.append(('pageIndex', local_var_params['page_index']))  # noqa: E501
        if 'page_size' in local_var_params and local_var_params['page_size'] is not None:  # noqa: E501
            query_params.append(('pageSize', local_var_params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/scenario/timed-delete', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_scenario_water_power_in_plant_auto_forecast_create_run_post(self, **kwargs):  # noqa: E501
        """滚动计算-厂内水动力，包括创建方案，设置边界，发送ModelDriver模型计算  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_scenario_water_power_in_plant_auto_forecast_create_run_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str tenant_id:
        :param int library_type:
        :param int business_type:
        :param str template_name:
        :param str outside_plant_tenant_id: 厂外水动力的租户ID
        :param str outside_plant_muid: 厂外水动力的输出点位-该模型要用到的结果点位，例如：升级补量进水总量|3c_inflow,升级补量进水总量|3c_inflow
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_scenario_water_power_in_plant_auto_forecast_create_run_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_scenario_water_power_in_plant_auto_forecast_create_run_post_with_http_info(self, **kwargs):  # noqa: E501
        """滚动计算-厂内水动力，包括创建方案，设置边界，发送ModelDriver模型计算  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_scenario_water_power_in_plant_auto_forecast_create_run_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str tenant_id:
        :param int library_type:
        :param int business_type:
        :param str template_name:
        :param str outside_plant_tenant_id: 厂外水动力的租户ID
        :param str outside_plant_muid: 厂外水动力的输出点位-该模型要用到的结果点位，例如：升级补量进水总量|3c_inflow,升级补量进水总量|3c_inflow
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'tenant_id',
            'library_type',
            'business_type',
            'template_name',
            'outside_plant_tenant_id',
            'outside_plant_muid'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_scenario_water_power_in_plant_auto_forecast_create_run_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'tenant_id' in local_var_params and local_var_params['tenant_id'] is not None:  # noqa: E501
            query_params.append(('tenantId', local_var_params['tenant_id']))  # noqa: E501
        if 'library_type' in local_var_params and local_var_params['library_type'] is not None:  # noqa: E501
            query_params.append(('libraryType', local_var_params['library_type']))  # noqa: E501
        if 'business_type' in local_var_params and local_var_params['business_type'] is not None:  # noqa: E501
            query_params.append(('businessType', local_var_params['business_type']))  # noqa: E501
        if 'template_name' in local_var_params and local_var_params['template_name'] is not None:  # noqa: E501
            query_params.append(('TemplateName', local_var_params['template_name']))  # noqa: E501
        if 'outside_plant_tenant_id' in local_var_params and local_var_params['outside_plant_tenant_id'] is not None:  # noqa: E501
            query_params.append(('outsidePlantTenantId', local_var_params['outside_plant_tenant_id']))  # noqa: E501
        if 'outside_plant_muid' in local_var_params and local_var_params['outside_plant_muid'] is not None:  # noqa: E501
            query_params.append(('outsidePlantMUID', local_var_params['outside_plant_muid']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/scenario/water-power-in-plant/auto-forecast/create-run', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_scenario_water_power_in_plant_auto_forecast_create_run_post_0(self, **kwargs):  # noqa: E501
        """滚动计算-厂内水动力，包括创建方案，设置边界，发送ModelDriver模型计算  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_scenario_water_power_in_plant_auto_forecast_create_run_post_0(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str tenant_id:
        :param int library_type:
        :param int business_type:
        :param str template_name:
        :param str outside_plant_tenant_id: 厂外水动力的租户ID
        :param str outside_plant_muid: 厂外水动力的输出点位-该模型要用到的结果点位，例如：升级补量进水总量|3c_inflow,升级补量进水总量|3c_inflow
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_scenario_water_power_in_plant_auto_forecast_create_run_post_0_with_http_info(**kwargs)  # noqa: E501

    def api_v1_scenario_water_power_in_plant_auto_forecast_create_run_post_0_with_http_info(self, **kwargs):  # noqa: E501
        """滚动计算-厂内水动力，包括创建方案，设置边界，发送ModelDriver模型计算  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_scenario_water_power_in_plant_auto_forecast_create_run_post_0_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str tenant_id:
        :param int library_type:
        :param int business_type:
        :param str template_name:
        :param str outside_plant_tenant_id: 厂外水动力的租户ID
        :param str outside_plant_muid: 厂外水动力的输出点位-该模型要用到的结果点位，例如：升级补量进水总量|3c_inflow,升级补量进水总量|3c_inflow
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'tenant_id',
            'library_type',
            'business_type',
            'template_name',
            'outside_plant_tenant_id',
            'outside_plant_muid'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_scenario_water_power_in_plant_auto_forecast_create_run_post_0" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'tenant_id' in local_var_params and local_var_params['tenant_id'] is not None:  # noqa: E501
            query_params.append(('tenantId', local_var_params['tenant_id']))  # noqa: E501
        if 'library_type' in local_var_params and local_var_params['library_type'] is not None:  # noqa: E501
            query_params.append(('libraryType', local_var_params['library_type']))  # noqa: E501
        if 'business_type' in local_var_params and local_var_params['business_type'] is not None:  # noqa: E501
            query_params.append(('businessType', local_var_params['business_type']))  # noqa: E501
        if 'template_name' in local_var_params and local_var_params['template_name'] is not None:  # noqa: E501
            query_params.append(('TemplateName', local_var_params['template_name']))  # noqa: E501
        if 'outside_plant_tenant_id' in local_var_params and local_var_params['outside_plant_tenant_id'] is not None:  # noqa: E501
            query_params.append(('outsidePlantTenantId', local_var_params['outside_plant_tenant_id']))  # noqa: E501
        if 'outside_plant_muid' in local_var_params and local_var_params['outside_plant_muid'] is not None:  # noqa: E501
            query_params.append(('outsidePlantMUID', local_var_params['outside_plant_muid']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/scenario/water-power-in-plant/auto-forecast/create-run', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_scenario_water_power_in_plant_max_min_create_run_post(self, **kwargs):  # noqa: E501
        """最大最小处理能力水量计算，包括创建方案，设置边界，发送ModelDriver模型计算  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_scenario_water_power_in_plant_max_min_create_run_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str tenant_id:
        :param int library_type:
        :param int business_type:
        :param str template_name:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_scenario_water_power_in_plant_max_min_create_run_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_scenario_water_power_in_plant_max_min_create_run_post_with_http_info(self, **kwargs):  # noqa: E501
        """最大最小处理能力水量计算，包括创建方案，设置边界，发送ModelDriver模型计算  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_scenario_water_power_in_plant_max_min_create_run_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str tenant_id:
        :param int library_type:
        :param int business_type:
        :param str template_name:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'tenant_id',
            'library_type',
            'business_type',
            'template_name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_scenario_water_power_in_plant_max_min_create_run_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'tenant_id' in local_var_params and local_var_params['tenant_id'] is not None:  # noqa: E501
            query_params.append(('tenantId', local_var_params['tenant_id']))  # noqa: E501
        if 'library_type' in local_var_params and local_var_params['library_type'] is not None:  # noqa: E501
            query_params.append(('libraryType', local_var_params['library_type']))  # noqa: E501
        if 'business_type' in local_var_params and local_var_params['business_type'] is not None:  # noqa: E501
            query_params.append(('businessType', local_var_params['business_type']))  # noqa: E501
        if 'template_name' in local_var_params and local_var_params['template_name'] is not None:  # noqa: E501
            query_params.append(('TemplateName', local_var_params['template_name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/scenario/water-power-in-plant/max-min/create-run', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_scenario_water_power_in_plant_max_min_create_run_post_0(self, **kwargs):  # noqa: E501
        """最大最小处理能力水量计算，包括创建方案，设置边界，发送ModelDriver模型计算  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_scenario_water_power_in_plant_max_min_create_run_post_0(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str tenant_id:
        :param int library_type:
        :param int business_type:
        :param str template_name:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_scenario_water_power_in_plant_max_min_create_run_post_0_with_http_info(**kwargs)  # noqa: E501

    def api_v1_scenario_water_power_in_plant_max_min_create_run_post_0_with_http_info(self, **kwargs):  # noqa: E501
        """最大最小处理能力水量计算，包括创建方案，设置边界，发送ModelDriver模型计算  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_scenario_water_power_in_plant_max_min_create_run_post_0_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str tenant_id:
        :param int library_type:
        :param int business_type:
        :param str template_name:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'tenant_id',
            'library_type',
            'business_type',
            'template_name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_scenario_water_power_in_plant_max_min_create_run_post_0" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'tenant_id' in local_var_params and local_var_params['tenant_id'] is not None:  # noqa: E501
            query_params.append(('tenantId', local_var_params['tenant_id']))  # noqa: E501
        if 'library_type' in local_var_params and local_var_params['library_type'] is not None:  # noqa: E501
            query_params.append(('libraryType', local_var_params['library_type']))  # noqa: E501
        if 'business_type' in local_var_params and local_var_params['business_type'] is not None:  # noqa: E501
            query_params.append(('businessType', local_var_params['business_type']))  # noqa: E501
        if 'template_name' in local_var_params and local_var_params['template_name'] is not None:  # noqa: E501
            query_params.append(('TemplateName', local_var_params['template_name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/scenario/water-power-in-plant/max-min/create-run', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    wd-domain-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wd_domain_service.configuration import Configuration


class BurstPipeValvesItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pipe_id': 'str',
        'gis_id': 'str',
        'x': 'float',
        'y': 'float'
    }

    attribute_map = {
        'pipe_id': 'pipeId',
        'gis_id': 'gisId',
        'x': 'x',
        'y': 'y'
    }

    def __init__(self, pipe_id=None, gis_id=None, x=None, y=None, local_vars_configuration=None):  # noqa: E501
        """BurstPipeValvesItem - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pipe_id = None
        self._gis_id = None
        self._x = None
        self._y = None
        self.discriminator = None

        self.pipe_id = pipe_id
        self.gis_id = gis_id
        if x is not None:
            self.x = x
        if y is not None:
            self.y = y

    @property
    def pipe_id(self):
        """Gets the pipe_id of this BurstPipeValvesItem.  # noqa: E501

        管段muid  # noqa: E501

        :return: The pipe_id of this BurstPipeValvesItem.  # noqa: E501
        :rtype: str
        """
        return self._pipe_id

    @pipe_id.setter
    def pipe_id(self, pipe_id):
        """Sets the pipe_id of this BurstPipeValvesItem.

        管段muid  # noqa: E501

        :param pipe_id: The pipe_id of this BurstPipeValvesItem.  # noqa: E501
        :type: str
        """

        self._pipe_id = pipe_id

    @property
    def gis_id(self):
        """Gets the gis_id of this BurstPipeValvesItem.  # noqa: E501

        爆管的位置  # noqa: E501

        :return: The gis_id of this BurstPipeValvesItem.  # noqa: E501
        :rtype: str
        """
        return self._gis_id

    @gis_id.setter
    def gis_id(self, gis_id):
        """Sets the gis_id of this BurstPipeValvesItem.

        爆管的位置  # noqa: E501

        :param gis_id: The gis_id of this BurstPipeValvesItem.  # noqa: E501
        :type: str
        """

        self._gis_id = gis_id

    @property
    def x(self):
        """Gets the x of this BurstPipeValvesItem.  # noqa: E501

        爆管的位置 - X  # noqa: E501

        :return: The x of this BurstPipeValvesItem.  # noqa: E501
        :rtype: float
        """
        return self._x

    @x.setter
    def x(self, x):
        """Sets the x of this BurstPipeValvesItem.

        爆管的位置 - X  # noqa: E501

        :param x: The x of this BurstPipeValvesItem.  # noqa: E501
        :type: float
        """

        self._x = x

    @property
    def y(self):
        """Gets the y of this BurstPipeValvesItem.  # noqa: E501

        爆管的位置 - Y  # noqa: E501

        :return: The y of this BurstPipeValvesItem.  # noqa: E501
        :rtype: float
        """
        return self._y

    @y.setter
    def y(self, y):
        """Sets the y of this BurstPipeValvesItem.

        爆管的位置 - Y  # noqa: E501

        :param y: The y of this BurstPipeValvesItem.  # noqa: E501
        :type: float
        """

        self._y = y

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BurstPipeValvesItem):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BurstPipeValvesItem):
            return True

        return self.to_dict() != other.to_dict()
